HmsScanErrors class
Object that contains Hms Scan Errors values.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- buildBitmap → const HmsScanError
- Try changing barcode content according to your error logs.
- decodeMultiAsyncCouldntFind → const HmsScanError
- Analyzer couldn't find any suitable barcode from the provided image.
- decodeMultiAsyncOnFailure → const HmsScanError
- Analyzer failed to respond. Try recalling the API.
- decodeMultiSyncCouldntFind → const HmsScanError
- Analyzer couldn't find any suitable barcode from the provided image.
- decodeWithBitmapError → const HmsScanError
- Analyzer couldn't find any suitable barcode from the provided image.
- hmsScanAnalyzerError → const HmsScanError
- Analyzer Error.
- mpCameraScanModeError → const HmsScanError
- Provided scan mode is not suitable for analyzer.
- mpChannelError → const HmsScanError
- Multi Processor channel initialization.
- remoteViewError → const HmsScanError
- Remote View Error.
- ScanNoDetected → const HmsScanError
- Decode.
- scanUtilNoCameraPermission → const HmsScanError
- Apply for the permission again.
- scanUtilNoReadPermission → const HmsScanError
- Apply for the permission again.